@@ -164,7 +164,9 @@ class FlaviusHeader(FlaviusBase):
 
         return super(FlaviusHeader, self).search(query=query)
     
-    def create(self, query=dict(slip_type=0)):
+    def create(self, query=None):
+        if query is None:
+            query = dict(slip_type=0)
         return super(FlaviusHeader, self).create(query=query)
 
 
